# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-25 02:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notify', '0003_auto_20160325_1920'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='actor_text',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Anonymous text for actor'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='nf_type',
            field=models.CharField(default='default', max_length=40, verbose_name='Type of notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='obj_text',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Anonymous text for action object'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='target_text',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Anonymous text for target'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='verb',
            field=models.CharField(max_length=100, verbose_name='Verb of the action'),
        ),
    ]
