# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-03-25 19:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notify', '0002_auto_20151221_0737'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='actor_url_text',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Anonymous URL for actor'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='obj_url_text',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Anonymous URL for action object'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='target_url_text',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Anonymous URL for target'),
        ),
    ]
